@@ -1,30 +1,30 @@
+mod builder;
 mod d4file;
 mod iter;
-mod builder;
 
+use builder::{D4Builder, D4Merger, D4Writer};
 use d4::Chrom;
-use pyo3::prelude::*;
 use d4file::D4File;
 use iter::D4Iter;
-use builder::{D4Builder, D4Writer};
+use pyo3::prelude::*;
 
 enum ReaderWrapper {
     LocalReader(d4::D4TrackReader),
-    RemoteReader(d4::ssio::D4TrackReader<d4::ssio::http::HttpReader>)
+    RemoteReader(d4::ssio::D4TrackReader<d4::ssio::http::HttpReader>),
 }
 
 impl ReaderWrapper {
     fn open(path: &str) -> PyResult<ReaderWrapper> {
         if path.starts_with("http://") || path.starts_with("https://") {
             let (path, track) = if let Some(split_pos) = path.rfind('#') {
-                    (&path[..split_pos], &path[split_pos + 1..])
+                (&path[..split_pos], &path[split_pos + 1..])
             } else {
                 (path, "")
             };
             let conn = d4::ssio::http::HttpReader::new(path)?;
             let reader = d4::ssio::D4TrackReader::from_reader(
-                conn, 
-                if track == "" { None } else { Some(track) }
+                conn,
+                if track == "" { None } else { Some(track) },
             )?;
             Ok(Self::RemoteReader(reader))
         } else {
@@ -43,10 +43,11 @@ impl ReaderWrapper {
             Self::LocalReader(what) => Ok(what),
             _ => {
                 return Err(std::io::Error::new(
-                    std::io::ErrorKind::Other, 
-                    "Operation only supports local D4 file"
-                ).into());
-            } 
+                    std::io::ErrorKind::Other,
+                    "Operation only supports local D4 file",
+                )
+                .into());
+            }
         }
     }
     fn into_local_reader(self) -> PyResult<d4::D4TrackReader> {
@@ -54,10 +55,11 @@ impl ReaderWrapper {
             Self::LocalReader(what) => Ok(what),
             _ => {
                 return Err(std::io::Error::new(
-                    std::io::ErrorKind::Other, 
-                    "Operation only supports local D4 file"
-                ).into());
-            } 
+                    std::io::ErrorKind::Other,
+                    "Operation only supports local D4 file",
+                )
+                .into());
+            }
         }
     }
     fn into_remote_reader(self) -> PyResult<d4::ssio::D4TrackReader<d4::ssio::http::HttpReader>> {
@@ -65,19 +67,22 @@ impl ReaderWrapper {
             Self::RemoteReader(what) => Ok(what),
             _ => {
                 return Err(std::io::Error::new(
-                    std::io::ErrorKind::Other, 
-                    "Operation only supports remote D4 file"
-                ).into());
-            } 
+                    std::io::ErrorKind::Other,
+                    "Operation only supports remote D4 file",
+                )
+                .into());
+            }
         }
     }
 }
 
 #[pymodule]
 pub fn pyd4(_py: Python<'_>, m: &PyModule) -> PyResult<()> {
+    env_logger::init();
     m.add_class::<D4File>()?;
     m.add_class::<D4Iter>()?;
     m.add_class::<D4Builder>()?;
     m.add_class::<D4Writer>()?;
+    m.add_class::<D4Merger>()?;
     Ok(())
 }
